# -*- coding: utf-8 -*-
"""Setup tests for this package."""
from collective.anonymouseditpatterns.testing import (
    COLLECTIVE_ANONYMOUSEDITPATTERNS_INTEGRATION_TESTING  # noqa: E501,
)
from plone import api
from plone.app.testing import setRoles, TEST_USER_ID

import unittest


try:
    from Products.CMFPlone.utils import get_installer
except ImportError:
    get_installer = None


class TestSetup(unittest.TestCase):
    """Test that collective.anonymouseditpatterns is properly installed."""

    layer = COLLECTIVE_ANONYMOUSEDITPATTERNS_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer['portal']
        if get_installer:
            self.installer = get_installer(self.portal, self.layer['request'])
        else:
            self.installer = api.portal.get_tool('portal_quickinstaller')

    def test_product_installed(self):
        """Test if collective.anonymouseditpatterns is installed."""
        self.assertTrue(self.installer.isProductInstalled(
            'collective.anonymouseditpatterns'))

    def test_browserlayer(self):
        """Test that ICollectiveAnonymouseditpatternsLayer is registered."""
        from collective.anonymouseditpatterns.interfaces import (
            ICollectiveAnonymouseditpatternsLayer)
        from plone.browserlayer import utils
        self.assertIn(
            ICollectiveAnonymouseditpatternsLayer,
            utils.registered_layers())


class TestUninstall(unittest.TestCase):

    layer = COLLECTIVE_ANONYMOUSEDITPATTERNS_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer['portal']
        if get_installer:
            self.installer = get_installer(self.portal, self.layer['request'])
        else:
            self.installer = api.portal.get_tool('portal_quickinstaller')
        roles_before = api.user.get_roles(TEST_USER_ID)
        setRoles(self.portal, TEST_USER_ID, ['Manager'])
        self.installer.uninstallProducts(['collective.anonymouseditpatterns'])
        setRoles(self.portal, TEST_USER_ID, roles_before)

    def test_product_uninstalled(self):
        """Test if collective.anonymouseditpatterns is cleanly uninstalled."""
        self.assertFalse(self.installer.isProductInstalled(
            'collective.anonymouseditpatterns'))

    def test_browserlayer_removed(self):
        """Test that ICollectiveAnonymouseditpatternsLayer is removed."""
        from collective.anonymouseditpatterns.interfaces import \
            ICollectiveAnonymouseditpatternsLayer
        from plone.browserlayer import utils
        self.assertNotIn(
            ICollectiveAnonymouseditpatternsLayer,
            utils.registered_layers())
